@@ -975,9 +975,10 @@ perform_initial_sign_in (GoaKerberosProvider *self,
                                                 object);
   g_simple_async_result_set_check_cancellable (operation_result, cancellable);
 
-  g_object_set_data (G_OBJECT (operation_result),
-                     "cancellable",
-                     cancellable);
+  g_object_set_data_full (G_OBJECT (operation_result),
+                          "cancellable",
+                          g_object_ref (cancellable),
+                          g_object_unref);
   g_object_set_data (G_OBJECT (operation_result),
                      "principal",
                      (gpointer)
@@ -988,6 +989,8 @@ perform_initial_sign_in (GoaKerberosProvider *self,
                                 (GAsyncReadyCallback)
                                 on_system_prompt_open_for_initial_sign_in,
                                 operation_result);
+
+  g_object_unref (cancellable);
 }
 
 static char *
@@ -1302,28 +1305,6 @@ start_over:
   return object;
 }
 
-static void
-show_account (GoaProvider *provider,
-              GoaClient   *client,
-              GoaObject   *object,
-              GtkBox      *vbox,
-              GtkGrid     *grid,
-              G_GNUC_UNUSED GtkGrid *dummy)
-{
-  gint row;
-
-  row = 0;
-
-  goa_util_add_account_info (grid, row++, object);
-
-  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
-                                                   /* Translators: This is a label for a series of
-                                                    * options switches. For example: “Use for Mail”. */
-                                                   _("Use for"),
-                                                   "ticketing-disabled",
-                                                   _("Network _Resources"));
-}
-
 static gboolean
 dbus_proxy_reload_properties_sync (GDBusProxy    *proxy,
                                    GCancellable  *cancellable)
@@ -1391,18 +1372,29 @@ ensure_credentials_sync (GoaProvider    *provider,
 
   if (identity == NULL || !goa_identity_service_identity_get_is_signed_in (identity))
     {
+      GError *lookup_error;
       gboolean ticket_synced;
 
+      lookup_error = NULL;
+
       g_mutex_unlock (&identity_manager_mutex);
       ticket_synced = get_ticket_sync (GOA_KERBEROS_PROVIDER (provider),
                                        object,
                                        FALSE /* Don't allow interaction */,
                                        cancellable,
-                                       error);
+                                       &lookup_error);
       g_mutex_lock (&identity_manager_mutex);
 
       if (!ticket_synced)
-        goto out;
+        {
+          translate_error (&lookup_error);
+          g_set_error_literal (error,
+                               GOA_ERROR,
+                               GOA_ERROR_NOT_AUTHORIZED,
+                               lookup_error->message);
+          g_error_free (lookup_error);
+          goto out;
+        }
 
       if (identity == NULL)
         identity = get_identity_from_object_manager (GOA_KERBEROS_PROVIDER (provider),
@@ -1679,6 +1671,5 @@ goa_kerberos_provider_class_init (GoaKerberosProviderClass *kerberos_class)
   provider_class->build_object               = build_object;
   provider_class->add_account                = add_account;
   provider_class->refresh_account            = refresh_account;
-  provider_class->show_account               = show_account;
   provider_class->ensure_credentials_sync    = ensure_credentials_sync;
 }
